==> ejc-bidprice-impl-3.0.0-20230215.105658-44-sources.jar: com/ejianc/business/bidprice/material/bean/PicketageQuotePurchaseDetailEntity.java <==
package com.ejianc.business.bidprice.material.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 材料定标询价-报价记录-采购清单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bidprice_material_picketage_quote_purchase_detail")
public class PicketageQuotePurchaseDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="quote_id")
    private Long quoteId; // 报价单id
    @TableField(value="picketage_quote_id")
    private Long picketageQuoteId; // 定标 报价记录 主表id
    @TableField(value="picketage_id")
    private Long picketageId; //主表id
    @TableField(value="source_id")
    private Long sourceId; // 来源id
    @TableField(value="inquiry_id")
    private Long inquiryId; // 询价单id
    @TableField(value="material_category_id")
    private Long materialCategoryId; // 物资分类Id
    @TableField(value="material_category_name")
    private String materialCategoryName; // 物资分类名称
    @TableField(value="material_id")
    private Long materialId; // 物资Id
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit")
    private String unit; // 计量单位
    @TableField(value="residue_num")
    private BigDecimal residueNum; // 剩余采购数量
    @TableField(value="refer_price")
    private BigDecimal referPrice; // 参考价
    @TableField(value="bid_num")
    private BigDecimal bidNum; // 中标数量
    @TableField(value="bid_price")
    private BigDecimal bidPrice; // 中标单价
    @TableField(value="bid_mny")
    private BigDecimal bidMny; // 中标金额
    @TableField(value="num")
    private BigDecimal num; // 数量

    public Long getPicketageId() {
        return picketageId;
    }

    public void setPicketageId(Long picketageId) {
        this.picketageId = picketageId;
    }

    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }

    public Long getQuoteId() {
        return quoteId;
    }

    public void setQuoteId(Long quoteId) {
        this.quoteId = quoteId;
    }
    public Long getPicketageQuoteId() {
        return picketageQuoteId;
    }

    public void setPicketageQuoteId(Long picketageQuoteId) {
        this.picketageQuoteId = picketageQuoteId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getInquiryId() {
        return inquiryId;
    }

    public void setInquiryId(Long inquiryId) {
        this.inquiryId = inquiryId;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getResidueNum() {
        return residueNum;
    }

    public void setResidueNum(BigDecimal residueNum) {
        this.residueNum = residueNum;
    }
    public BigDecimal getReferPrice() {
        return referPrice;
    }

    public void setReferPrice(BigDecimal referPrice) {
        this.referPrice = referPrice;
    }
    public BigDecimal getBidNum() {
        return bidNum;
    }

    public void setBidNum(BigDecimal bidNum) {
        this.bidNum = bidNum;
    }
    public BigDecimal getBidPrice() {
        return bidPrice;
    }

    public void setBidPrice(BigDecimal bidPrice) {
        this.bidPrice = bidPrice;
    }
    public BigDecimal getBidMny() {
        return bidMny;
    }

    public void setBidMny(BigDecimal bidMny) {
        this.bidMny = bidMny;
    }
    
}

==> ejc-bidprice-impl-3.0.0-20231116.070853-137-sources.jar: com/ejianc/business/bidprice/material/bean/PicketageQuotePurchaseDetailEntity.java <==
package com.ejianc.business.bidprice.material.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 材料定标询价-报价记录-采购清单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bidprice_material_picketage_quote_purchase_detail")
public class PicketageQuotePurchaseDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="quote_id")
    private Long quoteId; // 报价单id
    @TableField(value="picketage_quote_id")
    private Long picketageQuoteId; // 定标 报价记录 主表id
    @TableField(value="picketage_id")
    private Long picketageId; //主表id
    @TableField(value="source_id")
    private Long sourceId; // 来源id
    @TableField(value="inquiry_id")
    private Long inquiryId; // 询价单id
    @TableField(value="material_category_id")
    private Long materialCategoryId; // 物资分类Id
    @TableField(value="material_category_name")
    private String materialCategoryName; // 物资分类名称
    @TableField(value="material_id")
    private Long materialId; // 物资Id
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit")
    private String unit; // 计量单位
    @TableField(value="residue_num")
    private BigDecimal residueNum; // 剩余采购数量
    @TableField(value="refer_price")
    private BigDecimal referPrice; // 参考价
    @TableField(value="bid_num")
    private BigDecimal bidNum; // 中标数量
    @TableField(value="bid_price")
    private BigDecimal bidPrice; // 中标单价
    @TableField(value="bid_mny")
    private BigDecimal bidMny; // 中标金额
    @TableField(value="num")
    private BigDecimal num; // 数量

    @TableField(value="bid_price_no_tax")
    private BigDecimal bidPriceNoTax; // 中标单价
    @TableField(value="bid_mny_no_tax")
    private BigDecimal bidMnyNoTax; // 中标金额

    @TableField(value="bid_rate")
    private BigDecimal bidRate; // 中标税率

    public BigDecimal getBidRate() {
        return bidRate;
    }

    public void setBidRate(BigDecimal bidRate) {
        this.bidRate = bidRate;
    }

    public BigDecimal getBidPriceNoTax() {
        return bidPriceNoTax;
    }

    public void setBidPriceNoTax(BigDecimal bidPriceNoTax) {
        this.bidPriceNoTax = bidPriceNoTax;
    }

    public BigDecimal getBidMnyNoTax() {
        return bidMnyNoTax;
    }

    public void setBidMnyNoTax(BigDecimal bidMnyNoTax) {
        this.bidMnyNoTax = bidMnyNoTax;
    }

    public Long getPicketageId() {
        return picketageId;
    }

    public void setPicketageId(Long picketageId) {
        this.picketageId = picketageId;
    }

    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }

    public Long getQuoteId() {
        return quoteId;
    }

    public void setQuoteId(Long quoteId) {
        this.quoteId = quoteId;
    }
    public Long getPicketageQuoteId() {
        return picketageQuoteId;
    }

    public void setPicketageQuoteId(Long picketageQuoteId) {
        this.picketageQuoteId = picketageQuoteId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getInquiryId() {
        return inquiryId;
    }

    public void setInquiryId(Long inquiryId) {
        this.inquiryId = inquiryId;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getResidueNum() {
        return residueNum;
    }

    public void setResidueNum(BigDecimal residueNum) {
        this.residueNum = residueNum;
    }
    public BigDecimal getReferPrice() {
        return referPrice;
    }

    public void setReferPrice(BigDecimal referPrice) {
        this.referPrice = referPrice;
    }
    public BigDecimal getBidNum() {
        return bidNum;
    }

    public void setBidNum(BigDecimal bidNum) {
        this.bidNum = bidNum;
    }
    public BigDecimal getBidPrice() {
        return bidPrice;
    }

    public void setBidPrice(BigDecimal bidPrice) {
        this.bidPrice = bidPrice;
    }
    public BigDecimal getBidMny() {
        return bidMny;
    }

    public void setBidMny(BigDecimal bidMny) {
        this.bidMny = bidMny;
    }
    
}
